@@ -1,4 +1,4 @@
-use 5.010;
+use 5.008008;
 use strict;
 use warnings;
 
@@ -6,7 +6,7 @@ use warnings;
 	package Ask::Fallback;
 	
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.008';
+	our $VERSION   = '0.009';
 	
 	use Moo;
 	use Carp qw(croak);
@@ -20,17 +20,17 @@ use warnings;
 	
 	sub info {
 		my ($self, %o) = @_;
-		say STDERR $o{text};
+		print STDERR "$o{text}\n";
 	}
 	
 	sub warning {
 		my ($self, %o) = @_;
-		say STDERR "WARNING: $o{text}";
+		print STDERR "WARNING: $o{text}\n";
 	}
 	
 	sub error {
 		my ($self, %o) = @_;
-		say STDERR "ERROR: $o{text}";
+		print STDERR "ERROR: $o{text}\n";
 	}
 	
 	sub question
