@@ -1,4 +1,4 @@
-use 5.010;
+use 5.008008;
 use strict;
 use warnings;
 
@@ -6,7 +6,7 @@ use warnings;
 	package Ask::Gtk;
 	
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.008';
+	our $VERSION   = '0.009';
 	
 	use Moo;
 	use Gtk2 -init;
@@ -24,8 +24,8 @@ use warnings;
 	{
 		my ($self, %o) = @_;
 		
-		$o{messagedialog_type}    //= 'info';
-		$o{messagedialog_buttons} //= 'ok';
+		$o{messagedialog_type}    ||= 'info';
+		$o{messagedialog_buttons} ||= 'ok';
 		
 		my $msg = Gtk2::MessageDialog->new(
 			undef,
@@ -69,7 +69,7 @@ use warnings;
 		my $return;
 		
 		my $dialog = Gtk2::Dialog->new(
-			($o{title} // 'Message'),
+			($o{title} || 'Message'),
 			undef,
 			[qw/ modal destroy-with-parent /],
 			'gtk-ok' => 'none',
@@ -82,7 +82,7 @@ use warnings;
 		
 		my $entry = Gtk2::Entry->new;
 		$dialog->vbox->add($entry);
-		$entry->set_text($o{entry_text} // '');
+		$entry->set_text($o{entry_text} || '');
 		$entry->select_region(0, length $entry->get_text);
 		$entry->set_visibility(! $o{hide_text});
 		
@@ -106,7 +106,7 @@ use warnings;
 		my @return;
 		
 		my $dialog = Gtk2::FileChooserDialog->new(
-			($o{title} // $o{text} // 'File selection'),
+			($o{title} || $o{text} || 'File selection'),
 			undef,
 			$o{directory} ? 'select-folder' : $o{save} ? 'save' : 'open',
 			'gtk-ok' => 'none',
@@ -134,7 +134,7 @@ use warnings;
 		my $return;
 		
 		my $dialog = Gtk2::Dialog->new(
-			($o{title} // 'Choose'),
+			($o{title} || 'Choose'),
 			undef,
 			[qw/ modal destroy-with-parent /],
 			'gtk-ok' => 'none',
@@ -159,7 +159,7 @@ use warnings;
 		$tree_view->append_column($tree_column);
 		$dialog->vbox->set_size_request(300, 300);
 		$dialog->vbox->add($tree_view);
-		$tree_view->get_selection->set_mode($o{_tree_mode} // 'single');
+		$tree_view->get_selection->set_mode($o{_tree_mode} || 'single');
 		
 		my @return;
 		my $done = sub {
@@ -181,7 +181,7 @@ use warnings;
 	sub multiple_choice
 	{
 		my ($self, %o) = @_;
-		$o{title} //= 'Choose';
+		$o{title} ||= 'Choose';
 		$o{_tree_mode} = 'multiple';
 		return $self->_choice(%o);
 	}
@@ -189,7 +189,7 @@ use warnings;
 	sub single_choice
 	{
 		my ($self, %o) = @_;
-		$o{title} //= 'Choose one';
+		$o{title} ||= 'Choose one';
 		$o{_tree_mode} = 'single';
 		my ($r) = $self->_choice(%o);
 		return $r;
