@@ -1,7 +1,11 @@
+use 5.008008;
+use strict;
+use warnings;
+
 package AskX::AutoLang;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.008';
+our $VERSION   = '0.009';
 
 use Moo::Role;
 
